#
# $Id$
#   
# Copyright (C) 2003 Kai Sterker <kaisterker@linuxgames.com>
# Part of the Adonthell Project http://adonthell.linuxgames.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY.
#
# See the COPYING file for more details.
#

#
# This is the python counterpart to item_base.cc. It contains an
# item's most basic attributes. Any actual item should inherit
# from this class.
#
class item:

    def __init__ (self):
        # -- The item's name
        self.Name = ""

        # -- List of types the item belongs to
        self.Categories = []

        # -- Number of uses the item has left
        self.Charge = 0

        # -- Maximum number of uses the item can have
        self.MaxCharge = 0

        # -- The item's objective worth
        self.Value = 0

        # -- the item's basic weight
        self.Weight = 0.0

        # -- additional weight per charge
        self.WeightPerCharge = 0.0

                                        
    # -- add item to another category
    def add_category (self, category):
        if category not in self.Categories:
            self.Categories.append (category)
    
    
    # -- remove category
    def remove_category (self, category):
        if category in self.Categories:
            self.Categories.remove (category)
            
    
    # -- check whether item belongs to given category
    #    returns 1 if this is the case, 0 otherwise.
    def is_a (self, category):
        return category in self.Categories
                
    # -- get item's weight
    def weight (self):
        return self.Weight + self.WeightPerCharge * self.Charge

    
    # -- save item to disk
    #    file needs to be of type ogzstream
    def put_state (self, file):
        file.put_string (self.Name)
        file.put_uint16 (len (self.Categories))
        
        for category in self.Categories: file.put_string (category)
        
        file.put_uint16 (self.Charge)
        file.put_uint16 (self.MaxCharge)
        file.put_uint32 (self.Value)
        #file.put_float (self.Weight)
        #file.put_float (self.WeightPerCharge)
        
        
    # -- load item from disk
    #    file needs to be of type igzstream
    def get_state (self, file):
        self.Name = file.get_string ()
        categories = file.get_uint16 ()
        
        while categories > 0:
            self.add_category (file.get_string ())
            categories = categories - 1
        
        self.Charge = file.get_uint16 ()
        self.MaxCharge = file.get_uint16 ()
        self.Value = file.get_uint32 ()
        #self.Weight = file.get_float ()
        #self.WeightPerCharge = file.get_float ()
