#
# $Id$
#   
# Copyright (C) 2003 Kai Sterker <kaisterker@linuxgames.com>
# Part of the Adonthell Project http://adonthell.linuxgames.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY.
#
# See the COPYING file for more details.
#

import item
import adonthell

#
# A basic lightsource, such as a torch or candle. Using it will turn it
# on or off respectively, depending on its  current state. One all charges
# are used up, it will be deleted. (use rechargable_lightsource if that
# behaviour isn't desired).
#
class lightsource (item.item):

    def __init__(self):
        # -- init base class
        item.item.__init__(self)
        
        # -- we need an event_list for storing time_events
        self.Events = adonthell.event_list ()

        # -- duration of a charge (as gametime format string)
        self.Duration = "5m"
        
        # -- flag to indicate whether the torch is on or off
        self.IsBurning = 0

    def __del__(self):
        self.Events.clear ()
        
    def use (self, user):
		# -- turn it on
        if self.IsBurning == 0:

            # -- does it have enough charge?
            if self.Charge == 0: return

            # -- get event associated with the torch
            ConsumeEvent = self.Events.get_event ("consume")
            
            if ConsumeEvent == None:
                # -- register time event so it is consumed while burning
                #    a charge will last 5 minutes
                ConsumeEvent = adonthell.time_event (self.Duration)

                # -- callback to execute whenever a charge has been used
                #    up.
                ConsumeEvent.set_callback (self.on_burn)

                # -- repeat event as often as item has charges
                ConsumeEvent.set_repeat (self.Duration, self.Charge)

                # -- id to retrieve event later on
                ConsumeEvent.set_id ("consume")
                
                # -- Event lives on C++ side
                ConsumeEvent.thisown = 0
            
                # -- register consume event with event_list
                self.Events.add_event (ConsumeEvent)
            else:
                # -- resume event
                ConsumeEvent.resume ()
            
            self.IsBurning = 1

            # -- while it's burning, make it a lightsource
            self.add_category ("Lightsource")

            # -- start any graphical effects, etc
            # ...
  
        # -- switch it off
        else:
            self.IsBurning = 0
            
            # -- make sure event is not repeated
            self.Events.pause ()
            
            # -- not burning, so no lightsource
            self.remove_category ("Lightsource")

            # -- remove any graphical effects, etc
            # ...

    def on_burn (self):
        # -- decrease item's charge
        self.Charge = self.Charge - 1

        # -- if no charges left, turn off torch
        if self.Charge == 0:
            # -- the 'use' method will do that for us
            self.use (None)

            # -- as item became useless, delete it
            del self.this
            
    def put_state (self, file):
        # -- save state of parent class
        item.item.put_state (self, file)

        # -- save event list
        self.Events.put_state (file)

        # -- save own parameters
        file.put_string (self.Duration)
        file.put_bool (self.IsBurning)

    def get_state (self, file):
        # -- load state of parent class
        item.item.get_state (self, file)

        # -- load event list
        self.Events.get_state (file)

        # -- load own parameters
        self.Duration = file.get_string ()
        self.IsBurning = file.get_bool ()
