#                                   #
# $Id$
#
# Copyright (C) 2003 Kai Sterker <kaisterker@linuxgames.com>
# Part of the Adonthell Project http://adonthell.linuxgames.com
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY.
#
# See the COPYING file for more details.
#

import lightsource

#
# A lightsource that can be recharged, such as a lamp. Using it will turn it
# on or off respectively, depending on its  current state. Combining it with
# "Lampfuel" will restore charges.
#
class rechargable_lightsource (lightsource.lightsource):

    # -- override lightsource::on_burn, so the item will not be deleted when
    #    it runs out of charges
    def on_burn (self):
        # -- decrease item's charge
        self.Charge = self.Charge - 1

        # -- if no charges left, turn off torch
        if self.Charge == 0:
            # -- the 'use' method will do that for us
            self.use (None)

    # -- recharge item with "Lampfuel"
    def combine (self, item):
        fuel = item.get_instance ()
        if not fuel.is_a ("Lampfuel"): return

        fuel_needed = self.MaxCharge - self.Charge
        if fuel.Charge > fuel_needed:
            fuel.Charge = fuel.Charge - fuel_needed
            self.Charge = self.MaxCharge
        else:
            self.Charge = self.Charge + fuel.Charge
            del item
